@@ -2,8 +2,10 @@ __all__ = ['tty',     # libgtktty
 	   'xmhtml',  # libgtk-xmhtml
 	   'ui',      # libgnomeui
 	   'zvt',     # libzvt
+	   'applet',  # panel applets
+	   'capplet', # control center capplets
 	   'config', 'file', 'help', 'history',
-	   'metadata', 'mime', 'score', 'url'] # libgnome
+	   'metadata', 'mime', 'score', 'url', 'util'] # libgnome
 
 # set app_id and app_version where other modules can find it easily ...
 
