@@ -240,7 +240,9 @@ static int points_toarg(gpointer *boxed, PyObject *obj) {
   if (points) gnome_canvas_points_free(points);
   points = gnome_canvas_points_new(len/2);
   for (i = 0; i < len; i++) {
-    PyObject *item = PyNumber_Float(PySequence_GetItem(obj, i));
+    PyObject *item = PySequence_GetItem(obj, i);
+    Py_DECREF(item);
+    item = PyNumber_Float(item);
     if (!item) return 1;
     points->coords[i] = PyFloat_AsDouble(item);
     Py_DECREF(item);
@@ -305,6 +307,7 @@ static PyObject *_wrap_gnome_about_new(PyObject *self, PyObject *args) {
   authors[len] = NULL;
   for (i = 0; i < len; i++) {
     item = PySequence_GetItem(list, i);
+    Py_DECREF(item);
     if (!PyString_Check(item)) {
       PyErr_SetString(PyExc_TypeError, "sequence member is not a string");
       g_free(authors);
@@ -527,7 +530,9 @@ static PyObject *_wrap_gnome_canvas_item_affine_relative(PyObject *self, PyObjec
     return NULL;
   }
   for (i = 0; i < 6; i++) {
-    PyObject *sitem = PyNumber_Float(PySequence_GetItem(py_affine, i));
+    PyObject *sitem = PySequence_GetItem(py_affine, i);
+    Py_DECREF(sitem);
+    sitem = PyNumber_Float(sitem);
     if (sitem)
       affine[i] = PyFloat_AsDouble(sitem);
     else {
@@ -555,7 +560,9 @@ static PyObject *_wrap_gnome_canvas_item_affine_absolute(PyObject *self, PyObjec
     return NULL;
   }
   for (i = 0; i < 6; i++) {
-    PyObject *sitem = PyNumber_Float(PySequence_GetItem(py_affine, i));
+    PyObject *sitem = PySequence_GetItem(py_affine, i);
+    Py_DECREF(sitem);
+    sitem = PyNumber_Float(sitem);
     if (sitem)
       affine[i] = PyFloat_AsDouble(sitem);
     else {
@@ -634,6 +641,7 @@ static int read_vector(PyObject *obj, int *argc, char ***argv) {
   *argv = g_new(char *, *argc);
   for (i = 0; i < *argc; i++) {
     PyObject *item = PySequence_GetItem(obj, i);
+    Py_DECREF(item);
     if (!PyString_Check(item)) {
       PyErr_SetString(PyExc_TypeError, "sequence item not a string");
       g_free(*argv);
@@ -928,7 +936,7 @@ static PyObject *_wrap_gnome_mdi_generic_child_set_view_creator(PyObject *self,
     PyTuple_SetItem(tmp, 1, data);
     func = tmp;
   }
-  gnome_mdi_generic_child_set_view_creator_full(GNOME_MDI_GENERIC_CHILD(mdi),
+  gnome_mdi_generic_child_set_view_creator_full(GNOME_MDI_GENERIC_CHILD(PyGtk_Get(mdi)),
 						NULL,
 						PyGtk_CallbackMarshal,
 						func,
